/****************************************************************************
** Meta object code from reading C++ file 'mimesappsmanager.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../dde-file-manager/src/dfm-base/mimetype/mimesappsmanager.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'mimesappsmanager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_dfmbase__MimeAppsWorker_t {
    QByteArrayData data[8];
    char stringdata0[80];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_dfmbase__MimeAppsWorker_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_dfmbase__MimeAppsWorker_t qt_meta_stringdata_dfmbase__MimeAppsWorker = {
    {
QT_MOC_LITERAL(0, 0, 23), // "dfmbase::MimeAppsWorker"
QT_MOC_LITERAL(1, 24, 10), // "startWatch"
QT_MOC_LITERAL(2, 35, 0), // ""
QT_MOC_LITERAL(3, 36, 11), // "updateCache"
QT_MOC_LITERAL(4, 48, 9), // "writeData"
QT_MOC_LITERAL(5, 58, 4), // "path"
QT_MOC_LITERAL(6, 63, 7), // "content"
QT_MOC_LITERAL(7, 71, 8) // "readData"

    },
    "dfmbase::MimeAppsWorker\0startWatch\0\0"
    "updateCache\0writeData\0path\0content\0"
    "readData"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_dfmbase__MimeAppsWorker[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       4,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   34,    2, 0x0a /* Public */,
       3,    0,   35,    2, 0x0a /* Public */,
       4,    2,   36,    2, 0x0a /* Public */,
       7,    1,   41,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString, QMetaType::QByteArray,    5,    6,
    QMetaType::QByteArray, QMetaType::QString,    5,

       0        // eod
};

void dfmbase::MimeAppsWorker::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<MimeAppsWorker *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->startWatch(); break;
        case 1: _t->updateCache(); break;
        case 2: _t->writeData((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QByteArray(*)>(_a[2]))); break;
        case 3: { QByteArray _r = _t->readData((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QByteArray*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject dfmbase::MimeAppsWorker::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_dfmbase__MimeAppsWorker.data,
    qt_meta_data_dfmbase__MimeAppsWorker,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *dfmbase::MimeAppsWorker::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dfmbase::MimeAppsWorker::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_dfmbase__MimeAppsWorker.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int dfmbase::MimeAppsWorker::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 4;
    }
    return _id;
}
struct qt_meta_stringdata_dfmbase__MimesAppsManager_t {
    QByteArrayData data[3];
    char stringdata0[46];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_dfmbase__MimesAppsManager_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_dfmbase__MimesAppsManager_t qt_meta_stringdata_dfmbase__MimesAppsManager = {
    {
QT_MOC_LITERAL(0, 0, 25), // "dfmbase::MimesAppsManager"
QT_MOC_LITERAL(1, 26, 18), // "requestUpdateCache"
QT_MOC_LITERAL(2, 45, 0) // ""

    },
    "dfmbase::MimesAppsManager\0requestUpdateCache\0"
    ""
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_dfmbase__MimesAppsManager[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   19,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void,

       0        // eod
};

void dfmbase::MimesAppsManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<MimesAppsManager *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->requestUpdateCache(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (MimesAppsManager::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MimesAppsManager::requestUpdateCache)) {
                *result = 0;
                return;
            }
        }
    }
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject dfmbase::MimesAppsManager::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_dfmbase__MimesAppsManager.data,
    qt_meta_data_dfmbase__MimesAppsManager,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *dfmbase::MimesAppsManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dfmbase::MimesAppsManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_dfmbase__MimesAppsManager.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int dfmbase::MimesAppsManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void dfmbase::MimesAppsManager::requestUpdateCache()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
