/****************************************************************************
** Meta object code from reading C++ file 'extensionemblemmanager_p.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../../../dde-file-manager/src/plugins/common/dfmplugin-utils/extensionimpl/emblemimpl/extensionemblemmanager_p.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'extensionemblemmanager_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_dfmplugin_utils__EmblemIconWorker_t {
    QByteArrayData data[9];
    char stringdata0[140];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_dfmplugin_utils__EmblemIconWorker_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_dfmplugin_utils__EmblemIconWorker_t qt_meta_stringdata_dfmplugin_utils__EmblemIconWorker = {
    {
QT_MOC_LITERAL(0, 0, 33), // "dfmplugin_utils::EmblemIconWo..."
QT_MOC_LITERAL(1, 34, 17), // "emblemIconChanged"
QT_MOC_LITERAL(2, 52, 0), // ""
QT_MOC_LITERAL(3, 53, 4), // "path"
QT_MOC_LITERAL(4, 58, 26), // "QList<QPair<QString,int> >"
QT_MOC_LITERAL(5, 85, 11), // "emblemGroup"
QT_MOC_LITERAL(6, 97, 18), // "onFetchEmblemIcons"
QT_MOC_LITERAL(7, 116, 10), // "localPaths"
QT_MOC_LITERAL(8, 127, 12) // "onClearCache"

    },
    "dfmplugin_utils::EmblemIconWorker\0"
    "emblemIconChanged\0\0path\0"
    "QList<QPair<QString,int> >\0emblemGroup\0"
    "onFetchEmblemIcons\0localPaths\0"
    "onClearCache"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_dfmplugin_utils__EmblemIconWorker[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       3,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    2,   29,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       6,    1,   34,    2, 0x0a /* Public */,
       8,    0,   37,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void, QMetaType::QString, 0x80000000 | 4,    3,    5,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 4,    7,
    QMetaType::Void,

       0        // eod
};

void dfmplugin_utils::EmblemIconWorker::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<EmblemIconWorker *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->emblemIconChanged((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QList<QPair<QString,int> >(*)>(_a[2]))); break;
        case 1: _t->onFetchEmblemIcons((*reinterpret_cast< const QList<QPair<QString,int> >(*)>(_a[1]))); break;
        case 2: _t->onClearCache(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (EmblemIconWorker::*)(const QString & , const QList<QPair<QString,int>> & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&EmblemIconWorker::emblemIconChanged)) {
                *result = 0;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject dfmplugin_utils::EmblemIconWorker::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_dfmplugin_utils__EmblemIconWorker.data,
    qt_meta_data_dfmplugin_utils__EmblemIconWorker,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *dfmplugin_utils::EmblemIconWorker::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dfmplugin_utils::EmblemIconWorker::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_dfmplugin_utils__EmblemIconWorker.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int dfmplugin_utils::EmblemIconWorker::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void dfmplugin_utils::EmblemIconWorker::emblemIconChanged(const QString & _t1, const QList<QPair<QString,int>> & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
struct qt_meta_stringdata_dfmplugin_utils__ExtensionEmblemManagerPrivate_t {
    QByteArrayData data[1];
    char stringdata0[47];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_dfmplugin_utils__ExtensionEmblemManagerPrivate_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_dfmplugin_utils__ExtensionEmblemManagerPrivate_t qt_meta_stringdata_dfmplugin_utils__ExtensionEmblemManagerPrivate = {
    {
QT_MOC_LITERAL(0, 0, 46) // "dfmplugin_utils::ExtensionEmb..."

    },
    "dfmplugin_utils::ExtensionEmblemManagerPrivate"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_dfmplugin_utils__ExtensionEmblemManagerPrivate[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void dfmplugin_utils::ExtensionEmblemManagerPrivate::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject dfmplugin_utils::ExtensionEmblemManagerPrivate::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_dfmplugin_utils__ExtensionEmblemManagerPrivate.data,
    qt_meta_data_dfmplugin_utils__ExtensionEmblemManagerPrivate,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *dfmplugin_utils::ExtensionEmblemManagerPrivate::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dfmplugin_utils::ExtensionEmblemManagerPrivate::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_dfmplugin_utils__ExtensionEmblemManagerPrivate.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int dfmplugin_utils::ExtensionEmblemManagerPrivate::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
