/****************************************************************************
** Meta object code from reading C++ file 'tagbutton.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../../../dde-file-manager/src/plugins/common/dfmplugin-tag/widgets/tagbutton.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'tagbutton.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_dfmplugin_tag__TagButton_t {
    QByteArrayData data[7];
    char stringdata0[65];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_dfmplugin_tag__TagButton_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_dfmplugin_tag__TagButton_t qt_meta_stringdata_dfmplugin_tag__TagButton = {
    {
QT_MOC_LITERAL(0, 0, 24), // "dfmplugin_tag::TagButton"
QT_MOC_LITERAL(1, 25, 5), // "click"
QT_MOC_LITERAL(2, 31, 0), // ""
QT_MOC_LITERAL(3, 32, 5), // "color"
QT_MOC_LITERAL(4, 38, 5), // "enter"
QT_MOC_LITERAL(5, 44, 5), // "leave"
QT_MOC_LITERAL(6, 50, 14) // "checkedChanged"

    },
    "dfmplugin_tag::TagButton\0click\0\0color\0"
    "enter\0leave\0checkedChanged"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_dfmplugin_tag__TagButton[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       4,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       4,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   34,    2, 0x06 /* Public */,
       4,    0,   37,    2, 0x06 /* Public */,
       5,    0,   38,    2, 0x06 /* Public */,
       6,    0,   39,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void, QMetaType::QColor,    3,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void dfmplugin_tag::TagButton::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<TagButton *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->click((*reinterpret_cast< QColor(*)>(_a[1]))); break;
        case 1: _t->enter(); break;
        case 2: _t->leave(); break;
        case 3: _t->checkedChanged(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (TagButton::*)(QColor );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&TagButton::click)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (TagButton::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&TagButton::enter)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (TagButton::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&TagButton::leave)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (TagButton::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&TagButton::checkedChanged)) {
                *result = 3;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject dfmplugin_tag::TagButton::staticMetaObject = { {
    QMetaObject::SuperData::link<QFrame::staticMetaObject>(),
    qt_meta_stringdata_dfmplugin_tag__TagButton.data,
    qt_meta_data_dfmplugin_tag__TagButton,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *dfmplugin_tag::TagButton::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dfmplugin_tag::TagButton::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_dfmplugin_tag__TagButton.stringdata0))
        return static_cast<void*>(this);
    return QFrame::qt_metacast(_clname);
}

int dfmplugin_tag::TagButton::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QFrame::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void dfmplugin_tag::TagButton::click(QColor _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void dfmplugin_tag::TagButton::enter()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void dfmplugin_tag::TagButton::leave()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void dfmplugin_tag::TagButton::checkedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
