/****************************************************************************
** Meta object code from reading C++ file 'vaultactivesetunlockmethodview.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../../../dde-file-manager/src/plugins/filemanager/dfmplugin-vault/views/createvaultview/vaultactivesetunlockmethodview.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'vaultactivesetunlockmethodview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_dfmplugin_vault__VaultActiveSetUnlockMethodView_t {
    QByteArrayData data[17];
    char stringdata0[339];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_dfmplugin_vault__VaultActiveSetUnlockMethodView_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_dfmplugin_vault__VaultActiveSetUnlockMethodView_t qt_meta_stringdata_dfmplugin_vault__VaultActiveSetUnlockMethodView = {
    {
QT_MOC_LITERAL(0, 0, 47), // "dfmplugin_vault::VaultActiveS..."
QT_MOC_LITERAL(1, 48, 11), // "sigAccepted"
QT_MOC_LITERAL(2, 60, 0), // ""
QT_MOC_LITERAL(3, 61, 19), // "slotPasswordEditing"
QT_MOC_LITERAL(4, 81, 24), // "slotPasswordEditFinished"
QT_MOC_LITERAL(5, 106, 28), // "slotPasswordEditFocusChanged"
QT_MOC_LITERAL(6, 135, 6), // "bFocus"
QT_MOC_LITERAL(7, 142, 30), // "slotRepeatPasswordEditFinished"
QT_MOC_LITERAL(8, 173, 25), // "slotRepeatPasswordEditing"
QT_MOC_LITERAL(9, 199, 34), // "slotRepeatPasswordEditFocusCh..."
QT_MOC_LITERAL(10, 234, 23), // "slotGenerateEditChanged"
QT_MOC_LITERAL(11, 258, 3), // "str"
QT_MOC_LITERAL(12, 262, 18), // "slotNextBtnClicked"
QT_MOC_LITERAL(13, 281, 15), // "slotTypeChanged"
QT_MOC_LITERAL(14, 297, 5), // "index"
QT_MOC_LITERAL(15, 303, 22), // "slotLimiPasswordLength"
QT_MOC_LITERAL(16, 326, 12) // "passwordEdit"

    },
    "dfmplugin_vault::VaultActiveSetUnlockMethodView\0"
    "sigAccepted\0\0slotPasswordEditing\0"
    "slotPasswordEditFinished\0"
    "slotPasswordEditFocusChanged\0bFocus\0"
    "slotRepeatPasswordEditFinished\0"
    "slotRepeatPasswordEditing\0"
    "slotRepeatPasswordEditFocusChanged\0"
    "slotGenerateEditChanged\0str\0"
    "slotNextBtnClicked\0slotTypeChanged\0"
    "index\0slotLimiPasswordLength\0passwordEdit"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_dfmplugin_vault__VaultActiveSetUnlockMethodView[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      11,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   69,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       3,    0,   70,    2, 0x08 /* Private */,
       4,    0,   71,    2, 0x08 /* Private */,
       5,    1,   72,    2, 0x08 /* Private */,
       7,    0,   75,    2, 0x08 /* Private */,
       8,    0,   76,    2, 0x08 /* Private */,
       9,    1,   77,    2, 0x08 /* Private */,
      10,    1,   80,    2, 0x08 /* Private */,
      12,    0,   83,    2, 0x08 /* Private */,
      13,    1,   84,    2, 0x08 /* Private */,
      15,    1,   87,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    6,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    6,
    QMetaType::Void, QMetaType::QString,   11,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   14,
    QMetaType::Void, QMetaType::QString,   16,

       0        // eod
};

void dfmplugin_vault::VaultActiveSetUnlockMethodView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<VaultActiveSetUnlockMethodView *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->sigAccepted(); break;
        case 1: _t->slotPasswordEditing(); break;
        case 2: _t->slotPasswordEditFinished(); break;
        case 3: _t->slotPasswordEditFocusChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 4: _t->slotRepeatPasswordEditFinished(); break;
        case 5: _t->slotRepeatPasswordEditing(); break;
        case 6: _t->slotRepeatPasswordEditFocusChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 7: _t->slotGenerateEditChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 8: _t->slotNextBtnClicked(); break;
        case 9: _t->slotTypeChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 10: _t->slotLimiPasswordLength((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (VaultActiveSetUnlockMethodView::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&VaultActiveSetUnlockMethodView::sigAccepted)) {
                *result = 0;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject dfmplugin_vault::VaultActiveSetUnlockMethodView::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_meta_stringdata_dfmplugin_vault__VaultActiveSetUnlockMethodView.data,
    qt_meta_data_dfmplugin_vault__VaultActiveSetUnlockMethodView,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *dfmplugin_vault::VaultActiveSetUnlockMethodView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dfmplugin_vault::VaultActiveSetUnlockMethodView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_dfmplugin_vault__VaultActiveSetUnlockMethodView.stringdata0))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int dfmplugin_vault::VaultActiveSetUnlockMethodView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 11;
    }
    return _id;
}

// SIGNAL 0
void dfmplugin_vault::VaultActiveSetUnlockMethodView::sigAccepted()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
