/****************************************************************************
** Meta object code from reading C++ file 'sidebarview.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../../../dde-file-manager/src/plugins/filemanager/dfmplugin-sidebar/treeviews/sidebarview.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'sidebarview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_dfmplugin_sidebar__SideBarView_t {
    QByteArrayData data[8];
    char stringdata0[123];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_dfmplugin_sidebar__SideBarView_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_dfmplugin_sidebar__SideBarView_t qt_meta_stringdata_dfmplugin_sidebar__SideBarView = {
    {
QT_MOC_LITERAL(0, 0, 30), // "dfmplugin_sidebar::SideBarView"
QT_MOC_LITERAL(1, 31, 17), // "requestRemoveItem"
QT_MOC_LITERAL(2, 49, 0), // ""
QT_MOC_LITERAL(3, 50, 27), // "updateSeparatorVisibleState"
QT_MOC_LITERAL(4, 78, 19), // "onChangeExpandState"
QT_MOC_LITERAL(5, 98, 11), // "QModelIndex"
QT_MOC_LITERAL(6, 110, 5), // "index"
QT_MOC_LITERAL(7, 116, 6) // "expand"

    },
    "dfmplugin_sidebar::SideBarView\0"
    "requestRemoveItem\0\0updateSeparatorVisibleState\0"
    "onChangeExpandState\0QModelIndex\0index\0"
    "expand"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_dfmplugin_sidebar__SideBarView[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       3,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   29,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       3,    0,   30,    2, 0x0a /* Public */,
       4,    2,   31,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 5, QMetaType::Bool,    6,    7,

       0        // eod
};

void dfmplugin_sidebar::SideBarView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<SideBarView *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->requestRemoveItem(); break;
        case 1: _t->updateSeparatorVisibleState(); break;
        case 2: _t->onChangeExpandState((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (SideBarView::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&SideBarView::requestRemoveItem)) {
                *result = 0;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject dfmplugin_sidebar::SideBarView::staticMetaObject = { {
    QMetaObject::SuperData::link<DTreeView::staticMetaObject>(),
    qt_meta_stringdata_dfmplugin_sidebar__SideBarView.data,
    qt_meta_data_dfmplugin_sidebar__SideBarView,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *dfmplugin_sidebar::SideBarView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dfmplugin_sidebar::SideBarView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_dfmplugin_sidebar__SideBarView.stringdata0))
        return static_cast<void*>(this);
    return DTreeView::qt_metacast(_clname);
}

int dfmplugin_sidebar::SideBarView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = DTreeView::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void dfmplugin_sidebar::SideBarView::requestRemoveItem()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
